@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::FFI::Build 1.06 {
+package Dist::Zilla::Plugin::FFI::Build 1.07 {
 
   use 5.020;
   use Moose;
@@ -84,7 +84,7 @@ EOF2
           phase => 'runtime',
           type  => 'requires',
         },
-        "FFI::Platypus::Lang::@{[ $self->lang ]}",
+        "FFI::Platypus::Lang::@{[ $self->lang ]}" => 0,
       );
     }
 
@@ -94,7 +94,7 @@ EOF2
           phase => 'configure',
           type  => 'requires',
         },
-        "FFI::Build::File::@{[ $self->build ]}",
+        "FFI::Build::File::@{[ $self->build ]}" => 0,,
       );
     }
 
@@ -113,7 +113,7 @@ EOF2
 
     my $lang = $self->lang;
 
-    foreach my $file (@{ $self->zilla->files })
+    foreach my $file ((), @{ $self->zilla->files })
     {
       my $name = $file->name;
       my $prune = 0;
@@ -121,9 +121,13 @@ EOF2
       $prune = 1 if defined $lang && $lang eq 'Rust' && $name =~ m!^(t/|)ffi/target/!;
       if($prune)
       {
-        $self->log_debug([ 'pruning %s', $name ]);
+        $self->log([ 'pruning %s', $name ]);
         $self->zilla->prune_file($file);
       }
+      else
+      {
+        $self->log_debug([ 'NOT pruning %s', $name ]);
+      }
     }
 
   }
@@ -145,7 +149,7 @@ Dist::Zilla::Plugin::FFI::Build - Add FFI::Build to your Makefile.PL
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =head1 SYNOPSIS
 
